@@ -17,12 +17,15 @@ A script to add a project to the Software Configuration DB
 import logging
 import subprocess
 import re
+import json
 
 try:
-    import urllib2
-except Exception as _:
-    import urllib.request as urllib2
-import json
+    from urllib.parse import urlparse, urlsplit
+    from urllib.request import urlopen
+except ImportError:
+    from urlparse import urlparse, urlsplit
+    from urllib2 import urlopen
+    
 
 from LbCommon.CMake import getHeptoolsVersion, getGaudiUse
 from LbEnv import fixProjectCase
@@ -64,11 +67,7 @@ class GitlabProject:
         self.gitlabHTTPSURL = "https://gitlab.cern.ch"
         self.gitlabSSHURL = "ssh://git@gitlab.cern.ch:7999"
         self.gitlabViewURL = "https://gitlab.cern.ch"
-        try:
-            from urlparse import urlsplit
-        except Exception as _:
-            # Python 3 compatibility
-            from urllib.parse import urlparse
+
         self.sourceuri = sourceuri
         url = urlsplit(sourceuri)
         self.scheme = url.scheme
@@ -91,7 +90,7 @@ class GitlabProject:
                                 self.gitlabName)
         public_check_url = '%s/info/refs?service=git-upload-pack' % prefix
         try:
-            urllib2.urlopen(public_check_url)
+            urlopen(public_check_url)
         except Exception as _:
             return None
         commitID = None
@@ -107,7 +106,7 @@ class GitlabProject:
                 commitID = out.split()[0].strip()
             except Exception as _:
                 self.log.error("CommitID parse failed for %s" % out)
-        return commitID
+        return commitID.decode()
 
 
     def getURL(self, file=None):
@@ -133,10 +132,10 @@ class GitlabProject:
         self.toolchainurl = self.getURL("toolchain.cmake")
         self.log.info("Reading toolchain.cmake from: %s" %
                       self.toolchainurl)
-        response = urllib2.urlopen(self.toolchainurl)
+        response = urlopen(self.toolchainurl)
         data = response.read()
         self.log.debug("Got: %s" % self.toolchainurl)
-        return data
+        return data.decode()
 
     def getCMakeLists(self):
         """
@@ -146,14 +145,14 @@ class GitlabProject:
         self.cmakelistsurl = self.getURL("CMakeLists.txt")
         self.log.debug("Getting: %s" % self.cmakelistsurl)
         try:
-            response = urllib2.urlopen(self.cmakelistsurl)
+            response = urlopen(self.cmakelistsurl)
             data = response.read()
             self.log.debug("Got: %s" % self.cmakelistsurl)
         except Exception as _:
             self.log.info("Could not find CMakeLists at: %s" %
                           self.cmakelistsurl)
             raise
-        return data
+        return data.decode()
 
     def getProjectCMT(self):
         """
@@ -163,7 +162,7 @@ class GitlabProject:
         self.projectcmturl = self.getURL("cmt/project.cmt")
         self.log.debug("Getting: %s" % self.projectcmturl)
         try:
-            response = urllib2.urlopen(self.projectcmturl)
+            response = urlopen(self.projectcmturl)
             data = response.read()
             self.log.debug("Got: %s" % self.projectcmturl)
         except Exception as _:
@@ -181,7 +180,7 @@ class GitlabProject:
         self.projconfigurl = self.getURL("dist-tools/projectConfig.json")
         self.log.debug("Getting: %s" % self.projconfigurl)
         try:
-            response = urllib2.urlopen(self.projconfigurl)
+            response = urlopen(self.projconfigurl)
             data = response.read()
             self.log.debug("Got: %s" % self.projconfigurl)
         except Exception as e:
@@ -332,7 +331,6 @@ class AppImporter:
         else:
             sourceuri = alturi
 
-        from urlparse import urlsplit
         if sourceuri is not None:
             if urlsplit(sourceuri).scheme == "svn":
                 return False
@@ -353,7 +351,7 @@ class AppImporter:
         :param alturi: the alternative URI for the source URI
         :param saveURIinPV: flag used to notify SoftConfDB instance to persist
                             the sourceURI in the database
-        :param graph: local representations of the dependecies graph of the all
+        :param graph: local representations of the dependency graph of the all
                       imported projects
         :return: the top project imported node instance
         """
